# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"plot_sequence": "10_core_overview.ipynb",
         "plot_sequence_1d": "10_core_overview.ipynb",
         "get_alphabet": "11_core_elements.ipynb",
         "get_element_counts": "11_core_elements.ipynb",
         "get_first_positions": "11_core_elements.ipynb",
         "get_element_frequency": "11_core_elements.ipynb",
         "plot_element_counts": "11_core_elements.ipynb",
         "get_subsequences": "12_core_subsequences.ipynb",
         "get_ndistinct_subsequences": "12_core_subsequences.ipynb",
         "get_unique_ngrams": "13_core_ngrams.ipynb",
         "get_all_ngrams": "13_core_ngrams.ipynb",
         "get_ngram_universe": "13_core_ngrams.ipynb",
         "get_ngram_counts": "13_core_ngrams.ipynb",
         "plot_ngram_counts": "13_core_ngrams.ipynb",
         "get_transitions": "14_core_transitions.ipynb",
         "get_ntransitions": "14_core_transitions.ipynb",
         "get_transition_matrix": "14_core_transitions.ipynb",
         "plot_transition_matrix": "14_core_transitions.ipynb",
         "get_spells": "15_core_spells.ipynb",
         "get_longest_spell": "15_core_spells.ipynb",
         "get_spell_durations": "15_core_spells.ipynb",
         "is_recurrent": "16_core_statistics.ipynb",
         "get_entropy": "16_core_statistics.ipynb",
         "get_turbulence": "16_core_statistics.ipynb",
         "get_complexity": "16_core_statistics.ipynb",
         "get_routine": "16_core_statistics.ipynb",
         "plot_sequences": "20_multi_overview.ipynb",
         "are_recurrent": "21_multi_attributes.ipynb",
         "get_summary_statistic": "21_multi_attributes.ipynb",
         "get_routine_scores": "21_multi_attributes.ipynb",
         "get_synchrony": "21_multi_attributes.ipynb",
         "get_sequence_frequencies": "21_multi_attributes.ipynb",
         "get_motif": "22_multi_derivatives.ipynb",
         "get_modal_state": "22_multi_derivatives.ipynb",
         "get_optimal_distance": "23_multi_edit_distances.ipynb",
         "get_levenshtein_distance": "23_multi_edit_distances.ipynb",
         "get_hamming_distance": "23_multi_edit_distances.ipynb",
         "get_combinatorial_distance": "24_multi_nonalignment.ipynb"}

modules = ["core/__init__.py",
           "core/elements.py",
           "core/subsequences.py",
           "core/ngrams.py",
           "core/transitions.py",
           "core/spells.py",
           "core/statistics.py",
           "multi/__init__.py",
           "multi/attributes.py",
           "multi/derivatives.py",
           "multi/editdistances.py",
           "multi/nonalignment.py"]

doc_url = "https://pysan-dev.github.io/pysan/"

git_url = "https://github.com/pysan-dev/pysan/tree/master/"

def custom_doc_links(name): return None
